------------------------------
-- Localize Lua Globals
------------------------------
local _G = getfenv(0)
local select = _G.select
local pairs  = _G.pairs
local type   = _G.type

------------------------------
-- Addon Namespace
------------------------------
local MODNAME = "Skill Guide"
local addon   = LibStub("AceAddon-3.0"):GetAddon(MODNAME)
local L       = LibStub("AceLocale-3.0"):GetLocale(MODNAME)

------------------------------
-- WoW Namespace
------------------------------
local GetTradeSkillListLink = _G.GetTradeSkillListLink
local IsTradeSkillLinked = _G.IsTradeSkillLinked

local private = select(2, ...)

------------------------------
-- Event Handling Callbacks
------------------------------
function addon:TRADE_SKILL_SHOW()
   -- If this is our skill, save it
   if not IsTradeSkillLinked() then
      -- Register for updates and close
      --self:RegisterEvent("TRADE_SKILL_UPDATE")
      self:RegisterEvent("TRADE_SKILL_CLOSE")
         
      -- Get the profession info from DataStore
      local name = GetTradeSkillLine()
      local trade = DataStore:GetProfession(private.character, name)
      local spellId = select(3, DataStore:GetProfessionInfo(trade))
         
      -- Check if our information exists
      if not spellId then
         self:Print("spellId not set")
      end
      local key = format("%s", spellId)
      local skill = self.db.char.tradeskills[key]
      if not skill or type(skill) ~= "table" then
         self:Print("skill not set")
      end
         
      --@alpha@
      wipe(skill.optimal)
      --@end-alpha@
         
      if not skill.optimal or type(skill.optimal) ~= "table" or #skill.optimal == 0 then
         addon:BuildOptimalList(trade, spellId)
      end
   end -- of IsTradeSkillLinked
end -- of function
    
function addon:TRADE_SKILL_CLOSE()
   -- Unregister the close and update events
   --self:UnregisterEvent("TRADE_SKILL_UPDATE")
   self:UnregisterEvent("TRADE_SKILL_CLOSE")
end
--[[
do
  local last_update = 0
  local updater = CreateFrame("Frame", nil, UIParent)
  
  updater:Hide()
  updater:SetScript("OnUpdate",
                    function(self, elapsed)
                      last_update = last_update + elapsed
                      
                      if last_update >= 0.5 then -- make this dependent on profile information
                        local profession = GetTradeSkillLine()
                        
                        if profession ~= "UNKNOWN" then
                        end
                      end
                    end)

  function addon:TRADE_SKILL_UPDATE(...)
    if not updater:IsVisible() then
      last_update = 0
      updater:Show()
    end
  end
end -- of do
]]--